@@ -1560,6 +1560,13 @@ def _process_module_builtin_defaults():
     _process_module_definition('flask.templating',
             'newrelic.hooks.framework_flask',
             'instrument_flask_templating')
+    _process_module_definition('flask.blueprints',
+            'newrelic.hooks.framework_flask',
+            'instrument_flask_blueprints')
+
+    _process_module_definition('flask_compress',
+            'newrelic.hooks.middleware_flask_compress',
+            'instrument_flask_compress')
 
     #_process_module_definition('web.application',
     #        'newrelic.hooks.framework_webpy')
@@ -1681,6 +1688,10 @@ def _process_module_builtin_defaults():
     _process_module_definition('pyodbc',
             'newrelic.hooks.database_dbapi2')
 
+    _process_module_definition('pymssql',
+            'newrelic.hooks.database_pymssql',
+            'instrument_pymssql')
+
     _process_module_definition('psycopg2',
             'newrelic.hooks.database_psycopg2',
             'instrument_psycopg2')
@@ -2002,17 +2013,17 @@ def _setup_instrumentation():
 
     _process_function_profile_configuration()
 
-def _setup_extensions(): 
-    try: 
-        import pkg_resources 
-    except ImportError: 
-        return 
+def _setup_extensions():
+    try:
+        import pkg_resources
+    except ImportError:
+        return
 
-    group = 'newrelic.extension' 
+    group = 'newrelic.extension'
 
-    for entrypoint in pkg_resources.iter_entry_points(group=group): 
-        __import__(entrypoint.module_name) 
-        module = sys.modules[entrypoint.module_name] 
+    for entrypoint in pkg_resources.iter_entry_points(group=group):
+        __import__(entrypoint.module_name)
+        module = sys.modules[entrypoint.module_name]
         module.initialize()
 
 _console = None
