@@ -14,6 +14,11 @@ import logging
 import copy
 import socket
 
+try:
+    import urlparse
+except ImportError:
+    import urllib.parse as urlparse
+
 # The Settings objects and the global default settings. We create a
 # distinct type for each sub category of settings that the agent knows
 # about so that an error when accessing a non existant setting is more
@@ -26,6 +31,8 @@ class Settings(object):
         return repr(self.__dict__)
     def __iter__(self):
         return iter(flatten_settings(self).items())
+    def __contains__(self, item):
+        return hasattr(self, item)
 
 class ThreadProfilerSettings(Settings): pass
 class TransactionTracerSettings(Settings): pass
@@ -140,6 +147,8 @@ _settings.process_host.display_name = None
 
 _settings.monitor_mode = _environ_as_bool('NEW_RELIC_MONITOR_MODE', True)
 
+_settings.developer_mode = _environ_as_bool('NEW_RELIC_DEVELOPER_MODE', False)
+
 _settings.high_security = _environ_as_bool('NEW_RELIC_HIGH_SECURITY', False)
 
 _settings.collect_errors = True
@@ -214,6 +223,7 @@ _settings.browser_monitoring.loader_version = None
 _settings.browser_monitoring.debug = False
 _settings.browser_monitoring.ssl_for_http = None
 _settings.browser_monitoring.capture_attributes = False
+_settings.browser_monitoring.content_type = ['text/html']
 
 _settings.transaction_name.limit = None
 _settings.transaction_name.naming_scheme = os.environ.get(
@@ -255,6 +265,7 @@ _settings.debug.log_normalization_rules = False
 _settings.debug.log_raw_metric_data = False
 _settings.debug.log_normalized_metric_data = False
 _settings.debug.log_explain_plan_queries = False
+_settings.debug.log_autorum_middleware = False
 _settings.debug.record_transaction_failure = False
 _settings.debug.enable_coroutine_profiling = False
 _settings.debug.explain_plan_obfuscation = 'simple'
@@ -301,14 +312,39 @@ def flatten_settings(settings):
 
     return _flatten({}, None, settings)
 
-def global_settings_dump():
+def create_obfuscated_netloc(username, password, hostname, mask):
+    """Create a netloc string from hostname, username and password. If the
+    username and/or password is present, replace them with the obfuscation
+    mask. Otherwise, leave them out of netloc.
+
+    """
+
+    if username:
+        username = mask
+
+    if password:
+        password = mask
+
+    if username and password:
+        netloc = '%s:%s@%s' % (username, password, hostname)
+    elif username:
+        netloc = '%s@%s' % (username, hostname)
+    else:
+        netloc = hostname
+
+    return netloc
+
+def global_settings_dump(settings_object=None):
     """This returns dictionary of global settings flattened into a single
     key namespace rather than nested hierarchy. This is used to send the
     global settings configuration back to core application.
 
     """
 
-    settings = flatten_settings(_settings)
+    if settings_object is None:
+        settings_object = _settings
+
+    settings = flatten_settings(settings_object)
 
     # Strip out any sensitive settings as can be sent unencrypted.
     # The license key is being sent already, but no point sending
@@ -317,8 +353,40 @@ def global_settings_dump():
     del settings['license_key']
     del settings['api_key']
 
-    del settings['proxy_user']
-    del settings['proxy_pass']
+    # If proxy credentials are included in the settings, we obfuscate
+    # them before sending, rather than deleting.
+
+    obfuscated = '****'
+
+    if settings['proxy_user'] is not None:
+        settings['proxy_user'] = obfuscated
+
+    if settings['proxy_pass'] is not None:
+        settings['proxy_pass'] = obfuscated
+
+    # For the case of proxy_host we have to do a bit more work as it
+    # could be a URI which includes the username and password within
+    # it. What we do here is parse the value and if identified as a
+    # URI, we recompose it with the obfuscated username and password.
+
+    proxy_host = settings['proxy_host']
+
+    if proxy_host:
+        components = urlparse.urlparse(proxy_host)
+
+        if components.scheme:
+
+            netloc = create_obfuscated_netloc(components.username,
+                    components.password, components.hostname, obfuscated)
+
+            if components.port:
+                uri = '%s://%s:%s%s' % (components.scheme, netloc,
+                        components.port, components.path)
+            else:
+                uri = '%s://%s%s' % (components.scheme, netloc,
+                        components.path)
+
+            settings['proxy_host'] = uri
 
     return settings
 
